@@ -5,7 +5,8 @@ from typing import Text
 from django.conf import settings
 from django.db import connection, OperationalError
 
-from isc_common.common import blinkString, uuid4
+from isc_common.common import uuid4
+from sheduler import make_shedurer_tasks
 
 logger = logging.getLogger(__name__)
 
@@ -283,49 +284,35 @@ def drop_mat_view(mat_view_name) -> bool:
         return False
 
 
-def refresh_mat_view(mat_view_name, progressStack=None):
+def refresh_mat_view(mat_view_name, username=None):
+    from isc_common.ws.webSocket import WebSocket
+
     if not exists_base_object(mat_view_name):
         return
 
-    sql_txt = f'REFRESH MATERIALIZED VIEW CONCURRENTLY {mat_view_name};'
-    key = f'refresh_mat_view_{mat_view_name}'
-    settings.LOCKS.acquire(key)
-    try:
-        with connection.cursor() as cursor:
-            if progressStack != None:
-                progressStack.setContentsLabel(blinkString(f'Обновление материализованного преставления {mat_view_name}', bold=True))
-            cursor.execute(sql_txt)
-        settings.LOCKS.release(key)
-        if progressStack != None:
-            progressStack.close()
-        return True
-
-    except OperationalError:
-        sql_txt = f'REFRESH MATERIALIZED VIEW  {mat_view_name};'
+    def _refresh():
+        sql_txt = f'REFRESH MATERIALIZED VIEW {mat_view_name};'
         key = f'refresh_mat_view_{mat_view_name}'
         settings.LOCKS.acquire(key)
         try:
             with connection.cursor() as cursor:
-                if progressStack != None:
-                    progressStack.setContentsLabel(blinkString(f'Обновление материализованного преставления {mat_view_name}', bold=True))
                 cursor.execute(sql_txt)
             settings.LOCKS.release(key)
-            if progressStack != None:
-                progressStack.close()
-            return True
+
+            if username != None:
+                WebSocket.send_info_message(
+                    host=settings.WS_HOST,
+                    port=settings.WS_PORT,
+                    channel=f'common_{username}',
+                    message=f'Обновление {mat_view_name} выполнено.',
+                    logger=logger
+                )
 
         except Exception as ex:
             exc_info = sys.exc_info()
             logger.error(msg=ex, exc_info=exc_info)
             settings.LOCKS.release(key)
-            if progressStack != None:
-                progressStack.close()
-            return False
 
-    except Exception as ex:
-        exc_info = sys.exc_info()
-        logger.error(msg=ex, exc_info=exc_info)
-        settings.LOCKS.release(key)
-        if progressStack != None:
-            progressStack.close()
-        return False
+    make_shedurer_tasks(_refresh, when='1s')
+
+    return True
