@@ -1,6 +1,6 @@
 import logging
 
-from isc_common import setAttr, delAttr
+from isc_common import setAttr, delAttr, Wrapper
 from isc_common.http.RPCRequest import RPCRequest
 from isc_common.json import BytesToJson
 
@@ -159,6 +159,9 @@ class DSRequest(RPCRequest):
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
         return res
 
+    def get_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
+        return cls(**self.get_data(excluded_keys=excluded_keys))
+
     def get_old_data(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
@@ -173,6 +176,9 @@ class DSRequest(RPCRequest):
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
         return res
 
+    def get_old_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
+        return cls(**self.get_old_data(excluded_keys=excluded_keys))
+
     def get_all_data(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
